@@ -39,7 +39,7 @@ function rcube_text_editor(config, id)
     abs_url = location.href.replace(/[?#].*$/, '').replace(/\/$/, ''),
     conf = {
       selector: '#' + ($('#' + id).is('.mce_editor') ? id : 'fake-editor-id'),
-      cache_suffix: 's=4050700',
+      cache_suffix: 's=4050800',
       theme: 'modern',
       language: config.lang,
       content_css: rcmail.assets_path('program/resources/tinymce/content.css'),
@@ -182,7 +182,7 @@ function rcube_text_editor(config, id)
         rcmail.change_identity(elem);
 
       // Focus previously focused element
-      if (fe && fe.id != this.id) {
+      if (fe && fe.id != this.id && fe.nodeName != 'BODY') {
         window.focus(); // for WebKit (#1486674)
         fe.focus();
         rcmail.env.compose_focus_elem = null;
