@@ -56,6 +56,8 @@ tinymce.addI18n('fr_FR',{
 "OR": "OU",
 "Drop an image here": "Glisser une image ici",
 "Upload": "D\u00e9poser",
+"Block": "Bloquer",
+"Align": "Aligner",
 "Default": "Par d\u00e9faut",
 "Circle": "Cercle",
 "Disc": "Disque",
@@ -75,6 +77,7 @@ tinymce.addI18n('fr_FR',{
 "Source code": "Code source",
 "Insert\/Edit code sample": "Ins\u00e9rer \/ modifier une exemple de code",
 "Language": "Langue",
+"Code sample": "Extrait de code",
 "Color": "Couleur",
 "R": "R",
 "G": "V",
@@ -105,6 +108,8 @@ tinymce.addI18n('fr_FR',{
 "Premium plugins:": "Modules premium :",
 "Learn more...": "En savoir plus...",
 "You are using {0}": "Vous utilisez {0}",
+"Plugins": "Plugins",
+"Handy Shortcuts": "Raccourci",
 "Horizontal line": "Ligne horizontale",
 "Insert\/edit image": "Ins\u00e9rer\/modifier une image",
 "Image description": "Description de l'image",
@@ -119,7 +124,7 @@ tinymce.addI18n('fr_FR',{
 "Border": "Bordure",
 "Insert image": "Ins\u00e9rer une image",
 "Image": "Image",
-"Image list": "Image list",
+"Image list": "Liste d'images",
 "Rotate counterclockwise": "Rotation anti-horaire",
 "Rotate clockwise": "Rotation horaire",
 "Flip vertically": "Retournement vertical",
@@ -154,7 +159,7 @@ tinymce.addI18n('fr_FR',{
 "Paste or type a link": "Coller ou taper un lien",
 "The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "L'URL que vous avez entr\u00e9e semble \u00eatre une adresse e-mail. Voulez-vous ajouter le pr\u00e9fixe mailto: n\u00e9cessaire?",
 "The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "L'URL que vous avez entr\u00e9e semble \u00eatre un lien externe. Voulez-vous ajouter le pr\u00e9fixe http:\/\/ n\u00e9cessaire?",
-"Link list": "Link list",
+"Link list": "Liste de liens",
 "Insert video": "Ins\u00e9rer une vid\u00e9o",
 "Insert\/edit video": "Ins\u00e9rer\/modifier une vid\u00e9o",
 "Insert\/edit media": "Ins\u00e9rer\/modifier un m\u00e9dia",
@@ -232,7 +237,7 @@ tinymce.addI18n('fr_FR',{
 "Border color": "Couleur de la bordure",
 "Insert template": "Ajouter un th\u00e8me",
 "Templates": "Th\u00e8mes",
-"Template": "Template",
+"Template": "Mod\u00e8le",
 "Text color": "Couleur du texte",
 "Background color": "Couleur d'arri\u00e8re-plan",
 "Custom...": "Personnalis\u00e9...",
@@ -242,6 +247,7 @@ tinymce.addI18n('fr_FR',{
 "Show blocks": "Afficher les blocs",
 "Show invisible characters": "Afficher les caract\u00e8res invisibles",
 "Words: {0}": "Mots : {0}",
+"{0} words": "{0} mots",
 "File": "Fichier",
 "Edit": "Editer",
 "Insert": "Ins\u00e9rer",
@@ -249,5 +255,6 @@ tinymce.addI18n('fr_FR',{
 "Format": "Format",
 "Table": "Tableau",
 "Tools": "Outils",
+"Powered by {0}": "Propuls\u00e9 par {0}",
 "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Zone Texte Riche. Appuyer sur ALT-F9 pour le menu. Appuyer sur ALT-F10 pour la barre d'outils. Appuyer sur ALT-0 pour de l'aide."
 });
\ No newline at end of file
